package segmentation;

import shared.MacroOption;

/**Macro arguments*/
enum Arguments implements MacroOption<Arguments> {

   SOURCE("source", "Source", String.class, "Source directory"),
   DESTINATION("destination", "Destination", String.class, "Destination directory");

   private final String command, label, description;
   private final Class<?> parameterClass;

   /**Constructor.
    * @param command macro-recordable command
    * @param label short text as label for UI controls
    * @param parameterClass type of the parameter
    * @param description to be used as tooltip text*/
   Arguments(String command, String label, Class<?> parameterClass, String description) {
      this.command = command;
      this.label = label;
      this.description = description;
      this.parameterClass = parameterClass;
   }

   /**{@inheritDoc}*/
   @Override
   public String getCommand() {
      return command;
   }

   /**{@inheritDoc}*/
   @Override
   public String getLabel() {
      return label;
   }

   /**{@inheritDoc}*/
   @Override
   public Class<?> getParameterClass() {
      return parameterClass;
   }

   /**{@inheritDoc}*/
   @Override
   public String getDescription() {
      return description;
   }
}
