package segmentation;

import java.nio.file.Path;
import java.util.Scanner;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import shared.IJLogger;

/**Processor for GUV detection by cellpose*/
public class CellposeProcessor extends AbstractProcessor {

   @SuppressWarnings("RegExpRedundantEscape")
//   private static final Pattern CELLPOSE_PROGRESS_PATTERN = Pattern.compile(".+\\[INFO\\]\\s\\d+%\\|");
   private static final Pattern CELLPOSE_PROGRESS_PATTERN = Pattern.compile(".+FINDING");
   @SuppressWarnings("RegExpRedundantEscape")
   private static final Pattern CELLPOSE_ERROR_PATTERN = Pattern.compile(".+\\[ERROR\\]");

   CellposeProcessor(IJLogger logger, BatchInfo info) {
      super(logger, info);
   }

   @Override
   protected Void doInBackground() {
      setProgress(0);
      setIncrement(100d/(batchInfo.nPlanes));
      for (Path directory : batchInfo.tmpDirs) {
         if (isCancelled()) {
            break;
         }
         //noinspection ConstantConditions
         if (directory.toFile().list().length == 0) {
            continue;
         }
         ProcessBuilder builder = new ProcessBuilder(batchInfo.script.toString(), directory.toString());
         Process process;
         Scanner scanner = null;
         try {
            process = builder.start();
            scanner = new Scanner(process.getInputStream());
            String line;
            while (scanner.hasNextLine()) {
               if (isCancelled()) {
                  process.destroyForcibly();
                  break;
               }
               line = scanner.nextLine();
               System.out.println(line); //we want to be able to monitor this
               Matcher matcher = CELLPOSE_PROGRESS_PATTERN.matcher(line);
               if (matcher.find()) {
                  incrementProgress();
               } else {
                  matcher = CELLPOSE_ERROR_PATTERN.matcher(line);
                  if (matcher.find()) {
                     logger.error(line);
                  }
               }
            }
            int returnValue = process.waitFor();
            if (returnValue != 0) {
               logger.error("cellpose finished with errors.");
            }
         } catch (Exception ignored) { //is thrown if the SwingWorker is cancelled by the dialog
         } finally {
            if (scanner != null) {
               scanner.close();
            }
         }
      }
      setProgress(100);
      return null;
   }

   @Override
   public void done() {
      new PostProcessor(logger, batchInfo).execute();
   }
}
