package shared;

/**Common interface for {@link Enum} classes used as macro options.<br>
 * <br><i>Note:</i> To make full use of this interface, implementing classes should be wrapped in a
 * generic {@link MacroOptions} object*/
@SuppressWarnings("unused")
public interface MacroOption<T extends Enum<?>> {

   /**Returns the command of this option.
    * @return the command*/
   String getCommand();

   /**Returns a UI element label of this option.
    * @return the label*/
   String getLabel();

   /**Returns the class of parameters of this option. Supported classes:<br>
    *   {@link Boolean#TYPE}<br>
    *   {@link Integer#TYPE}<br>
    *   {@link Double#TYPE}<br>
    *   {@link String}<br>
    *   {@link MacroOption}
    * @return the class*/
   Class<?> getParameterClass();

   /**Returns a descriptive text for this option.
    * @return the label*/
   String getDescription();
}
